"""Dose GUI for TDD: package metadata."""

# Be careful: this file is imported by setup.py!

__version__ = "1.2.1"
__author__ = "Danilo de Jesus da Silva Bellini"
__author_email__  = "danilo.bellini@gmail.com"
__url__ = "https://github.com/danilobellini/dose"
